# coding: utf-8

"""
    Catalog Sampling API

    <p>The Catalog Sampling API offers functionality related to the Collibra Data Catalog application.<br/> It is mainly focused on facilitating the ingestion of information into Data Catalog.<br/> The API enables you to more easily connect Data Catalog to sources that are not necessarily natively supported in the product.</p>  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Job(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'created_by': 'str',
        'created_on': 'int',
        'last_modified_by': 'str',
        'last_modified_on': 'int',
        'system': 'bool',
        'resource_type': 'str',
        'name': 'str',
        'type': 'str',
        'user_id': 'str',
        'progress_percentage': 'float',
        'start_date': 'int',
        'end_date': 'int',
        'state': 'str',
        'message': 'str'
    }

    attribute_map = {
        'id': 'id',
        'created_by': 'createdBy',
        'created_on': 'createdOn',
        'last_modified_by': 'lastModifiedBy',
        'last_modified_on': 'lastModifiedOn',
        'system': 'system',
        'resource_type': 'resourceType',
        'name': 'name',
        'type': 'type',
        'user_id': 'userId',
        'progress_percentage': 'progressPercentage',
        'start_date': 'startDate',
        'end_date': 'endDate',
        'state': 'state',
        'message': 'message'
    }

    def __init__(self, id=None, created_by=None, created_on=None, last_modified_by=None, last_modified_on=None, system=None, resource_type=None, name=None, type=None, user_id=None, progress_percentage=None, start_date=None, end_date=None, state=None, message=None):  # noqa: E501
        """Job - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._created_by = None
        self._created_on = None
        self._last_modified_by = None
        self._last_modified_on = None
        self._system = None
        self._resource_type = None
        self._name = None
        self._type = None
        self._user_id = None
        self._progress_percentage = None
        self._start_date = None
        self._end_date = None
        self._state = None
        self._message = None
        self.discriminator = None
        self.id = id
        if created_by is not None:
            self.created_by = created_by
        if created_on is not None:
            self.created_on = created_on
        if last_modified_by is not None:
            self.last_modified_by = last_modified_by
        if last_modified_on is not None:
            self.last_modified_on = last_modified_on
        if system is not None:
            self.system = system
        self.resource_type = resource_type
        if name is not None:
            self.name = name
        if type is not None:
            self.type = type
        if user_id is not None:
            self.user_id = user_id
        if progress_percentage is not None:
            self.progress_percentage = progress_percentage
        if start_date is not None:
            self.start_date = start_date
        if end_date is not None:
            self.end_date = end_date
        if state is not None:
            self.state = state
        if message is not None:
            self.message = message

    @property
    def id(self):
        """Gets the id of this Job.  # noqa: E501

        The id of the represented object (entity).  # noqa: E501

        :return: The id of this Job.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Job.

        The id of the represented object (entity).  # noqa: E501

        :param id: The id of this Job.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def created_by(self):
        """Gets the created_by of this Job.  # noqa: E501

        The id of the user that created this resource.  # noqa: E501

        :return: The created_by of this Job.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this Job.

        The id of the user that created this resource.  # noqa: E501

        :param created_by: The created_by of this Job.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def created_on(self):
        """Gets the created_on of this Job.  # noqa: E501

        The timestamp (in UTC time standard) of the creation of this resource.  # noqa: E501

        :return: The created_on of this Job.  # noqa: E501
        :rtype: int
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this Job.

        The timestamp (in UTC time standard) of the creation of this resource.  # noqa: E501

        :param created_on: The created_on of this Job.  # noqa: E501
        :type: int
        """

        self._created_on = created_on

    @property
    def last_modified_by(self):
        """Gets the last_modified_by of this Job.  # noqa: E501

        The id of the user who modified this resource the last time.  # noqa: E501

        :return: The last_modified_by of this Job.  # noqa: E501
        :rtype: str
        """
        return self._last_modified_by

    @last_modified_by.setter
    def last_modified_by(self, last_modified_by):
        """Sets the last_modified_by of this Job.

        The id of the user who modified this resource the last time.  # noqa: E501

        :param last_modified_by: The last_modified_by of this Job.  # noqa: E501
        :type: str
        """

        self._last_modified_by = last_modified_by

    @property
    def last_modified_on(self):
        """Gets the last_modified_on of this Job.  # noqa: E501

        The timestamp (in UTC time standard) of the last modification of this resource.  # noqa: E501

        :return: The last_modified_on of this Job.  # noqa: E501
        :rtype: int
        """
        return self._last_modified_on

    @last_modified_on.setter
    def last_modified_on(self, last_modified_on):
        """Sets the last_modified_on of this Job.

        The timestamp (in UTC time standard) of the last modification of this resource.  # noqa: E501

        :param last_modified_on: The last_modified_on of this Job.  # noqa: E501
        :type: int
        """

        self._last_modified_on = last_modified_on

    @property
    def system(self):
        """Gets the system of this Job.  # noqa: E501

        Whether this is a system resource or not.  # noqa: E501

        :return: The system of this Job.  # noqa: E501
        :rtype: bool
        """
        return self._system

    @system.setter
    def system(self, system):
        """Sets the system of this Job.

        Whether this is a system resource or not.  # noqa: E501

        :param system: The system of this Job.  # noqa: E501
        :type: bool
        """

        self._system = system

    @property
    def resource_type(self):
        """Gets the resource_type of this Job.  # noqa: E501

        The type of this resource, i.e. [Community, Asset, Domain, Attribute, Relation, WorkflowInstance].   # noqa: E501

        :return: The resource_type of this Job.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this Job.

        The type of this resource, i.e. [Community, Asset, Domain, Attribute, Relation, WorkflowInstance].   # noqa: E501

        :param resource_type: The resource_type of this Job.  # noqa: E501
        :type: str
        """
        if resource_type is None:
            raise ValueError("Invalid value for `resource_type`, must not be `None`")  # noqa: E501
        allowed_values = ["View", "Asset", "Community", "Domain", "AssetType", "DomainType", "Status", "User", "ClassificationMatch", "UserGroup", "Attribute", "StringAttribute", "ScriptAttribute", "BooleanAttribute", "DateAttribute", "NumericAttribute", "SingleValueListAttribute", "MultiValueListAttribute", "Comment", "Attachment", "Responsibility", "Workflow", "Job", "Relation", "RelationType", "ComplexRelation", "ComplexRelationType", "ArticulationRule", "Assignment", "Scope", "RelationTrace", "ValidationRule", "DataQualityRule", "DataQualityMetric", "Address", "InstantMessagingAccount", "Email", "PhoneNumber", "Website", "Activity", "FormProperty", "WorkflowTask", "ActivityChange", "WorkflowInstance", "Role", "AttributeType", "BooleanAttributeType", "DateAttributeType", "DateTimeAttributeType", "MultiValueListAttributeType", "NumericAttributeType", "ScriptAttributeType", "SingleValueListAttributeType", "StringAttributeType", "ViewSharingRule", "ViewAssignmentRule", "JdbcDriverFile", "JdbcDriver", "JdbcIngestionProperties", "CsvIngestionProperties", "ExcelIngestionProperties", "ConnectionStringParameter", "AssignedCharacteristicType", "Notification", "Tag", "ComplexRelationLegType", "ComplexRelationAttributeType", "ComplexRelationLeg", "BaseDataType", "AdvancedDataType", "DiagramPicture", "DiagramPictureSharingRule", "DiagramPictureAssignmentRule", "Rating", "Classification", "PhysicalDataConnector", "Context"]  # noqa: E501
        if resource_type not in allowed_values:
            raise ValueError(
                "Invalid value for `resource_type` ({0}), must be one of {1}"  # noqa: E501
                .format(resource_type, allowed_values)
            )

        self._resource_type = resource_type

    @property
    def name(self):
        """Gets the name of this Job.  # noqa: E501

        The name of the resource.  # noqa: E501

        :return: The name of this Job.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Job.

        The name of the resource.  # noqa: E501

        :param name: The name of this Job.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def type(self):
        """Gets the type of this Job.  # noqa: E501

        The type of the job.  # noqa: E501

        :return: The type of this Job.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Job.

        The type of the job.  # noqa: E501

        :param type: The type of this Job.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def user_id(self):
        """Gets the user_id of this Job.  # noqa: E501

        The ID of the user that initiated this job.  # noqa: E501

        :return: The user_id of this Job.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this Job.

        The ID of the user that initiated this job.  # noqa: E501

        :param user_id: The user_id of this Job.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def progress_percentage(self):
        """Gets the progress_percentage of this Job.  # noqa: E501

        The progress percentage of the job.  # noqa: E501

        :return: The progress_percentage of this Job.  # noqa: E501
        :rtype: float
        """
        return self._progress_percentage

    @progress_percentage.setter
    def progress_percentage(self, progress_percentage):
        """Sets the progress_percentage of this Job.

        The progress percentage of the job.  # noqa: E501

        :param progress_percentage: The progress_percentage of this Job.  # noqa: E501
        :type: float
        """

        self._progress_percentage = progress_percentage

    @property
    def start_date(self):
        """Gets the start_date of this Job.  # noqa: E501

        The start date of the job.  # noqa: E501

        :return: The start_date of this Job.  # noqa: E501
        :rtype: int
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this Job.

        The start date of the job.  # noqa: E501

        :param start_date: The start_date of this Job.  # noqa: E501
        :type: int
        """

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this Job.  # noqa: E501

        The end date of the job.  # noqa: E501

        :return: The end_date of this Job.  # noqa: E501
        :rtype: int
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this Job.

        The end date of the job.  # noqa: E501

        :param end_date: The end_date of this Job.  # noqa: E501
        :type: int
        """

        self._end_date = end_date

    @property
    def state(self):
        """Gets the state of this Job.  # noqa: E501

        The state of the job.  # noqa: E501

        :return: The state of this Job.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this Job.

        The state of the job.  # noqa: E501

        :param state: The state of this Job.  # noqa: E501
        :type: str
        """
        allowed_values = ["WAITING", "RUNNING", "CANCELING", "COMPLETED", "CANCELED", "ERROR"]  # noqa: E501
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state` ({0}), must be one of {1}"  # noqa: E501
                .format(state, allowed_values)
            )

        self._state = state

    @property
    def message(self):
        """Gets the message of this Job.  # noqa: E501

        The message of the job.  # noqa: E501

        :return: The message of this Job.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this Job.

        The message of the job.  # noqa: E501

        :param message: The message of this Job.  # noqa: E501
        :type: str
        """

        self._message = message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Job, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Job):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    Catalog Sampling API

    <p>The Catalog Sampling API offers functionality related to the Collibra Data Catalog application.<br/> It is mainly focused on facilitating the ingestion of information into Data Catalog.<br/> The API enables you to more easily connect Data Catalog to sources that are not necessarily natively supported in the product.</p>  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from collibra_catalog_sampling.api.samples_api import SamplesApi
# import ApiClient
from collibra_catalog_sampling.api_client import ApiClient
from collibra_catalog_sampling.configuration import Configuration
# import models into sdk package
from collibra_catalog_sampling.models.column_paged_response import ColumnPagedResponse
from collibra_catalog_sampling.models.job import Job
from collibra_catalog_sampling.models.read_samples_response import ReadSamplesResponse
from collibra_catalog_sampling.models.request_samples_response import RequestSamplesResponse
from collibra_catalog_sampling.models.sample_column import SampleColumn
from collibra_catalog_sampling.models.standard_error_response import StandardErrorResponse



# coding: utf-8

"""
    Catalog Sampling API

    <p>The Catalog Sampling API offers functionality related to the Collibra Data Catalog application.<br/> It is mainly focused on facilitating the ingestion of information into Data Catalog.<br/> The API enables you to more easily connect Data Catalog to sources that are not necessarily natively supported in the product.</p>  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class StandardErrorResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'status_code': 'int',
        'title_message': 'str',
        'help_message': 'str',
        'user_message': 'str',
        'error_code': 'str'
    }

    attribute_map = {
        'status_code': 'statusCode',
        'title_message': 'titleMessage',
        'help_message': 'helpMessage',
        'user_message': 'userMessage',
        'error_code': 'errorCode'
    }

    def __init__(self, status_code=None, title_message=None, help_message=None, user_message=None, error_code=None):  # noqa: E501
        """StandardErrorResponse - a model defined in Swagger"""  # noqa: E501
        self._status_code = None
        self._title_message = None
        self._help_message = None
        self._user_message = None
        self._error_code = None
        self.discriminator = None
        if status_code is not None:
            self.status_code = status_code
        if title_message is not None:
            self.title_message = title_message
        if help_message is not None:
            self.help_message = help_message
        if user_message is not None:
            self.user_message = user_message
        if error_code is not None:
            self.error_code = error_code

    @property
    def status_code(self):
        """Gets the status_code of this StandardErrorResponse.  # noqa: E501

        HTTP response code  # noqa: E501

        :return: The status_code of this StandardErrorResponse.  # noqa: E501
        :rtype: int
        """
        return self._status_code

    @status_code.setter
    def status_code(self, status_code):
        """Sets the status_code of this StandardErrorResponse.

        HTTP response code  # noqa: E501

        :param status_code: The status_code of this StandardErrorResponse.  # noqa: E501
        :type: int
        """

        self._status_code = status_code

    @property
    def title_message(self):
        """Gets the title_message of this StandardErrorResponse.  # noqa: E501


        :return: The title_message of this StandardErrorResponse.  # noqa: E501
        :rtype: str
        """
        return self._title_message

    @title_message.setter
    def title_message(self, title_message):
        """Sets the title_message of this StandardErrorResponse.


        :param title_message: The title_message of this StandardErrorResponse.  # noqa: E501
        :type: str
        """

        self._title_message = title_message

    @property
    def help_message(self):
        """Gets the help_message of this StandardErrorResponse.  # noqa: E501


        :return: The help_message of this StandardErrorResponse.  # noqa: E501
        :rtype: str
        """
        return self._help_message

    @help_message.setter
    def help_message(self, help_message):
        """Sets the help_message of this StandardErrorResponse.


        :param help_message: The help_message of this StandardErrorResponse.  # noqa: E501
        :type: str
        """

        self._help_message = help_message

    @property
    def user_message(self):
        """Gets the user_message of this StandardErrorResponse.  # noqa: E501


        :return: The user_message of this StandardErrorResponse.  # noqa: E501
        :rtype: str
        """
        return self._user_message

    @user_message.setter
    def user_message(self, user_message):
        """Sets the user_message of this StandardErrorResponse.


        :param user_message: The user_message of this StandardErrorResponse.  # noqa: E501
        :type: str
        """

        self._user_message = user_message

    @property
    def error_code(self):
        """Gets the error_code of this StandardErrorResponse.  # noqa: E501


        :return: The error_code of this StandardErrorResponse.  # noqa: E501
        :rtype: str
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """Sets the error_code of this StandardErrorResponse.


        :param error_code: The error_code of this StandardErrorResponse.  # noqa: E501
        :type: str
        """

        self._error_code = error_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StandardErrorResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StandardErrorResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Catalog Sampling API

    <p>The Catalog Sampling API offers functionality related to the Collibra Data Catalog application.<br/> It is mainly focused on facilitating the ingestion of information into Data Catalog.<br/> The API enables you to more easily connect Data Catalog to sources that are not necessarily natively supported in the product.</p>  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import collibra_catalog_sampling
from collibra_catalog_sampling.api.samples_api import SamplesApi  # noqa: E501
from collibra_catalog_sampling.rest import ApiException


class TestSamplesApi(unittest.TestCase):
    """SamplesApi unit test stubs"""

    def setUp(self):
        self.api = SamplesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_read_samples(self):
        """Test case for read_samples

        Read sample data from the Collibra cloud repository or Edge cache  # noqa: E501
        """
        pass

    def test_request_samples(self):
        """Test case for request_samples

        Create a request to collect and cache sample data for an Edge data source  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Catalog Sampling API

    <p>The Catalog Sampling API offers functionality related to the Collibra Data Catalog application.<br/> It is mainly focused on facilitating the ingestion of information into Data Catalog.<br/> The API enables you to more easily connect Data Catalog to sources that are not necessarily natively supported in the product.</p>  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ReadSamplesResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'data_available': 'bool',
        'can_request_additional_data': 'bool',
        'column_paged_response': 'ColumnPagedResponse',
        'error': 'StandardErrorResponse'
    }

    attribute_map = {
        'data_available': 'dataAvailable',
        'can_request_additional_data': 'canRequestAdditionalData',
        'column_paged_response': 'columnPagedResponse',
        'error': 'error'
    }

    def __init__(self, data_available=None, can_request_additional_data=None, column_paged_response=None, error=None):  # noqa: E501
        """ReadSamplesResponse - a model defined in Swagger"""  # noqa: E501
        self._data_available = None
        self._can_request_additional_data = None
        self._column_paged_response = None
        self._error = None
        self.discriminator = None
        if data_available is not None:
            self.data_available = data_available
        if can_request_additional_data is not None:
            self.can_request_additional_data = can_request_additional_data
        if column_paged_response is not None:
            self.column_paged_response = column_paged_response
        if error is not None:
            self.error = error

    @property
    def data_available(self):
        """Gets the data_available of this ReadSamplesResponse.  # noqa: E501

        Whether any sample data is available for the columns in the response.  # noqa: E501

        :return: The data_available of this ReadSamplesResponse.  # noqa: E501
        :rtype: bool
        """
        return self._data_available

    @data_available.setter
    def data_available(self, data_available):
        """Sets the data_available of this ReadSamplesResponse.

        Whether any sample data is available for the columns in the response.  # noqa: E501

        :param data_available: The data_available of this ReadSamplesResponse.  # noqa: E501
        :type: bool
        """

        self._data_available = data_available

    @property
    def can_request_additional_data(self):
        """Gets the can_request_additional_data of this ReadSamplesResponse.  # noqa: E501

        Whether the requestSamples API can be called to query the target database for sample data.  # noqa: E501

        :return: The can_request_additional_data of this ReadSamplesResponse.  # noqa: E501
        :rtype: bool
        """
        return self._can_request_additional_data

    @can_request_additional_data.setter
    def can_request_additional_data(self, can_request_additional_data):
        """Sets the can_request_additional_data of this ReadSamplesResponse.

        Whether the requestSamples API can be called to query the target database for sample data.  # noqa: E501

        :param can_request_additional_data: The can_request_additional_data of this ReadSamplesResponse.  # noqa: E501
        :type: bool
        """

        self._can_request_additional_data = can_request_additional_data

    @property
    def column_paged_response(self):
        """Gets the column_paged_response of this ReadSamplesResponse.  # noqa: E501


        :return: The column_paged_response of this ReadSamplesResponse.  # noqa: E501
        :rtype: ColumnPagedResponse
        """
        return self._column_paged_response

    @column_paged_response.setter
    def column_paged_response(self, column_paged_response):
        """Sets the column_paged_response of this ReadSamplesResponse.


        :param column_paged_response: The column_paged_response of this ReadSamplesResponse.  # noqa: E501
        :type: ColumnPagedResponse
        """

        self._column_paged_response = column_paged_response

    @property
    def error(self):
        """Gets the error of this ReadSamplesResponse.  # noqa: E501


        :return: The error of this ReadSamplesResponse.  # noqa: E501
        :rtype: StandardErrorResponse
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this ReadSamplesResponse.


        :param error: The error of this ReadSamplesResponse.  # noqa: E501
        :type: StandardErrorResponse
        """

        self._error = error

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ReadSamplesResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReadSamplesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Catalog Sampling API

    <p>The Catalog Sampling API offers functionality related to the Collibra Data Catalog application.<br/> It is mainly focused on facilitating the ingestion of information into Data Catalog.<br/> The API enables you to more easily connect Data Catalog to sources that are not necessarily natively supported in the product.</p>  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ColumnPagedResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'column_offset': 'int',
        'column_limit': 'int',
        'column_total': 'int',
        'columns': 'list[SampleColumn]'
    }

    attribute_map = {
        'column_offset': 'columnOffset',
        'column_limit': 'columnLimit',
        'column_total': 'columnTotal',
        'columns': 'columns'
    }

    def __init__(self, column_offset=None, column_limit=None, column_total=None, columns=None):  # noqa: E501
        """ColumnPagedResponse - a model defined in Swagger"""  # noqa: E501
        self._column_offset = None
        self._column_limit = None
        self._column_total = None
        self._columns = None
        self.discriminator = None
        if column_offset is not None:
            self.column_offset = column_offset
        if column_limit is not None:
            self.column_limit = column_limit
        if column_total is not None:
            self.column_total = column_total
        if columns is not None:
            self.columns = columns

    @property
    def column_offset(self):
        """Gets the column_offset of this ColumnPagedResponse.  # noqa: E501

        The number of results to skip in the response.  # noqa: E501

        :return: The column_offset of this ColumnPagedResponse.  # noqa: E501
        :rtype: int
        """
        return self._column_offset

    @column_offset.setter
    def column_offset(self, column_offset):
        """Sets the column_offset of this ColumnPagedResponse.

        The number of results to skip in the response.  # noqa: E501

        :param column_offset: The column_offset of this ColumnPagedResponse.  # noqa: E501
        :type: int
        """

        self._column_offset = column_offset

    @property
    def column_limit(self):
        """Gets the column_limit of this ColumnPagedResponse.  # noqa: E501

        The maximum number of results in the response.  # noqa: E501

        :return: The column_limit of this ColumnPagedResponse.  # noqa: E501
        :rtype: int
        """
        return self._column_limit

    @column_limit.setter
    def column_limit(self, column_limit):
        """Sets the column_limit of this ColumnPagedResponse.

        The maximum number of results in the response.  # noqa: E501

        :param column_limit: The column_limit of this ColumnPagedResponse.  # noqa: E501
        :type: int
        """

        self._column_limit = column_limit

    @property
    def column_total(self):
        """Gets the column_total of this ColumnPagedResponse.  # noqa: E501

        The total number of results in the response.  # noqa: E501

        :return: The column_total of this ColumnPagedResponse.  # noqa: E501
        :rtype: int
        """
        return self._column_total

    @column_total.setter
    def column_total(self, column_total):
        """Sets the column_total of this ColumnPagedResponse.

        The total number of results in the response.  # noqa: E501

        :param column_total: The column_total of this ColumnPagedResponse.  # noqa: E501
        :type: int
        """

        self._column_total = column_total

    @property
    def columns(self):
        """Gets the columns of this ColumnPagedResponse.  # noqa: E501

        The column array containing the sample data.  # noqa: E501

        :return: The columns of this ColumnPagedResponse.  # noqa: E501
        :rtype: list[SampleColumn]
        """
        return self._columns

    @columns.setter
    def columns(self, columns):
        """Sets the columns of this ColumnPagedResponse.

        The column array containing the sample data.  # noqa: E501

        :param columns: The columns of this ColumnPagedResponse.  # noqa: E501
        :type: list[SampleColumn]
        """

        self._columns = columns

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ColumnPagedResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ColumnPagedResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Catalog Sampling API

    <p>The Catalog Sampling API offers functionality related to the Collibra Data Catalog application.<br/> It is mainly focused on facilitating the ingestion of information into Data Catalog.<br/> The API enables you to more easily connect Data Catalog to sources that are not necessarily natively supported in the product.</p>  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import collibra_catalog_sampling
from collibra_catalog_sampling.models.standard_error_response import StandardErrorResponse  # noqa: E501
from collibra_catalog_sampling.rest import ApiException


class TestStandardErrorResponse(unittest.TestCase):
    """StandardErrorResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testStandardErrorResponse(self):
        """Test StandardErrorResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = collibra_catalog_sampling.models.standard_error_response.StandardErrorResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Catalog Sampling API

    <p>The Catalog Sampling API offers functionality related to the Collibra Data Catalog application.<br/> It is mainly focused on facilitating the ingestion of information into Data Catalog.<br/> The API enables you to more easily connect Data Catalog to sources that are not necessarily natively supported in the product.</p>  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SampleColumn(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'display_name': 'str',
        'table_name': 'str',
        'samples': 'list[str]',
        'sampling_status': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'display_name': 'displayName',
        'table_name': 'tableName',
        'samples': 'samples',
        'sampling_status': 'samplingStatus'
    }

    def __init__(self, id=None, name=None, display_name=None, table_name=None, samples=None, sampling_status=None):  # noqa: E501
        """SampleColumn - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._display_name = None
        self._table_name = None
        self._samples = None
        self._sampling_status = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if display_name is not None:
            self.display_name = display_name
        if table_name is not None:
            self.table_name = table_name
        if samples is not None:
            self.samples = samples
        if sampling_status is not None:
            self.sampling_status = sampling_status

    @property
    def id(self):
        """Gets the id of this SampleColumn.  # noqa: E501

        The ID of the column asset.  # noqa: E501

        :return: The id of this SampleColumn.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SampleColumn.

        The ID of the column asset.  # noqa: E501

        :param id: The id of this SampleColumn.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this SampleColumn.  # noqa: E501

        The name of the column asset.  # noqa: E501

        :return: The name of this SampleColumn.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SampleColumn.

        The name of the column asset.  # noqa: E501

        :param name: The name of this SampleColumn.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def display_name(self):
        """Gets the display_name of this SampleColumn.  # noqa: E501

        The display name of the column asset.  # noqa: E501

        :return: The display_name of this SampleColumn.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this SampleColumn.

        The display name of the column asset.  # noqa: E501

        :param display_name: The display_name of this SampleColumn.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def table_name(self):
        """Gets the table_name of this SampleColumn.  # noqa: E501

        The table asset name the column asset belongs to.  # noqa: E501

        :return: The table_name of this SampleColumn.  # noqa: E501
        :rtype: str
        """
        return self._table_name

    @table_name.setter
    def table_name(self, table_name):
        """Sets the table_name of this SampleColumn.

        The table asset name the column asset belongs to.  # noqa: E501

        :param table_name: The table_name of this SampleColumn.  # noqa: E501
        :type: str
        """

        self._table_name = table_name

    @property
    def samples(self):
        """Gets the samples of this SampleColumn.  # noqa: E501

        Sample data for a given column asset.  # noqa: E501

        :return: The samples of this SampleColumn.  # noqa: E501
        :rtype: list[str]
        """
        return self._samples

    @samples.setter
    def samples(self, samples):
        """Sets the samples of this SampleColumn.

        Sample data for a given column asset.  # noqa: E501

        :param samples: The samples of this SampleColumn.  # noqa: E501
        :type: list[str]
        """

        self._samples = samples

    @property
    def sampling_status(self):
        """Gets the sampling_status of this SampleColumn.  # noqa: E501

        The processing status for column assets. The column can be missing (not found in the cache) or forbidden if the user lacks permissions.   # noqa: E501

        :return: The sampling_status of this SampleColumn.  # noqa: E501
        :rtype: str
        """
        return self._sampling_status

    @sampling_status.setter
    def sampling_status(self, sampling_status):
        """Sets the sampling_status of this SampleColumn.

        The processing status for column assets. The column can be missing (not found in the cache) or forbidden if the user lacks permissions.   # noqa: E501

        :param sampling_status: The sampling_status of this SampleColumn.  # noqa: E501
        :type: str
        """
        allowed_values = ["OK", "MISSING", "FORBIDDEN"]  # noqa: E501
        if sampling_status not in allowed_values:
            raise ValueError(
                "Invalid value for `sampling_status` ({0}), must be one of {1}"  # noqa: E501
                .format(sampling_status, allowed_values)
            )

        self._sampling_status = sampling_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SampleColumn, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SampleColumn):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Catalog Sampling API

    <p>The Catalog Sampling API offers functionality related to the Collibra Data Catalog application.<br/> It is mainly focused on facilitating the ingestion of information into Data Catalog.<br/> The API enables you to more easily connect Data Catalog to sources that are not necessarily natively supported in the product.</p>  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from setuptools import setup, find_packages  # noqa: H301

NAME = "collibra-catalog_sampling_100"
VERSION = "1.0.0"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

with open("README.md", "r") as f:
    DESCRIPTION = f.read()

setup(
    name=NAME,
    version=VERSION,
    description="Catalog Sampling API",
    author_email="",
    url="",
    keywords=["Swagger", "Catalog Sampling API"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description=DESCRIPTION,
    long_description_content_type="text/markdown"
)



# coding: utf-8

"""
    Catalog Sampling API

    <p>The Catalog Sampling API offers functionality related to the Collibra Data Catalog application.<br/> It is mainly focused on facilitating the ingestion of information into Data Catalog.<br/> The API enables you to more easily connect Data Catalog to sources that are not necessarily natively supported in the product.</p>  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RequestSamplesResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'new_job': 'bool',
        'job': 'Job'
    }

    attribute_map = {
        'new_job': 'newJob',
        'job': 'job'
    }

    def __init__(self, new_job=None, job=None):  # noqa: E501
        """RequestSamplesResponse - a model defined in Swagger"""  # noqa: E501
        self._new_job = None
        self._job = None
        self.discriminator = None
        if new_job is not None:
            self.new_job = new_job
        if job is not None:
            self.job = job

    @property
    def new_job(self):
        """Gets the new_job of this RequestSamplesResponse.  # noqa: E501

        Whether this is a newly created job or one that is in progress.  # noqa: E501

        :return: The new_job of this RequestSamplesResponse.  # noqa: E501
        :rtype: bool
        """
        return self._new_job

    @new_job.setter
    def new_job(self, new_job):
        """Sets the new_job of this RequestSamplesResponse.

        Whether this is a newly created job or one that is in progress.  # noqa: E501

        :param new_job: The new_job of this RequestSamplesResponse.  # noqa: E501
        :type: bool
        """

        self._new_job = new_job

    @property
    def job(self):
        """Gets the job of this RequestSamplesResponse.  # noqa: E501


        :return: The job of this RequestSamplesResponse.  # noqa: E501
        :rtype: Job
        """
        return self._job

    @job.setter
    def job(self, job):
        """Sets the job of this RequestSamplesResponse.


        :param job: The job of this RequestSamplesResponse.  # noqa: E501
        :type: Job
        """

        self._job = job

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RequestSamplesResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RequestSamplesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
